<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:dk="kelis.fr:dokiel" exclude-result-prefixes="sc sp dk">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="yes"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	<xsl:variable name="vId" select="alphaHash(getIdNode(..))"/>
	<xsl:variable name="vImgProps" select="parseXml(getProps(gotoSubModel(sp:img),'nav'))/props/image"/>
	<xsl:variable name="vImgUri" select="getUrl(gotoSubModel(sp:img),'nav')"/>
	<xsl:variable name="vImg" select="parseXml(getContent(gotoSubModel(sp:img),'img'))/img"/>
	<xsl:variable name="vRatio" select="$vImgProps/@transformedWidth div $vImgProps/@nativeWidth"/>
	<xsl:variable name="vArea" select="$vImgProps/@nativeWidth * $vImgProps/@nativeHeight"/>
	<xsl:variable name="vSmallZoneLimit" select="'1000'"/>
	<xsl:template match="*">
		<span style="display:none;">cliquer sur une zone pour connaître son commentaire</span>
		<scBlock class="screenBk">
			<hx class="screenBk_ti">
				<span>
					<xsl:value-of select="getContent(currentModel(),'title')" disable-output-escaping="yes"/>
				</span>
			</hx>
			<div class="screenBk_co">
				<xsl:if test="sp:desc">
					<div class="screenDesc">
						<xsl:value-of select="getContent(gotoSubModel(sp:desc),'')" disable-output-escaping="yes"/>
					</div>
				</xsl:if>
				<div class="screenFra">
					<xsl:variable name="vImgId" select="concat($vId,generate-id(sp:img))"/>
					<div id="{$vImgId}" class="screenImgFra" style="position:relative;height:{$vImgProps/@transformedHeight}px;">
						<div class="screenImg" style="position:relative;height:{$vImgProps/@transformedHeight}px;width:{$vImgProps/@transformedWidth}px;">
							<img src="{$vImgUri}" width="{$vImgProps/@transformedWidth}" height="{$vImgProps/@transformedHeight}" class="" alt="{getFullTitleText(gotoSubModel(sp:img),'')}"/>
							<xsl:apply-templates select="sp:zone" mode="zones"/>
						</div>
					</div>
					<ol class="screenZones">
						<xsl:for-each select="sp:zone">
							<xsl:variable name="vLeft" select="number(returnFirst(substring-before(dk:screenZoneMeta/sp:geo/sp:coords,','),0))"/>
							<xsl:variable name="vTop" select="number(returnFirst(substring-before(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),0))"/>
							<xsl:variable name="vWidth" select="number(returnFirst(substring-before(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',') - $vLeft,0))"/>
							<xsl:variable name="vHeight" select="number(returnFirst(substring-after(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',') - $vTop,0))"/>
							<xsl:variable name="vZoneArea" select="$vWidth * $vHeight"/>
							<li class="screenZone" id="{concat($vId,generate-id(.))}">
								<xsl:if test="dk:screenZoneMeta/sp:title">
									<div class="screenZone_ti">
										<span>
											<xsl:value-of select="dk:screenZoneMeta/sp:title"/>
										</span>
									</div>
								</xsl:if>
								<table>
									<tr>
										<td class="screenZone_pre">
											<alternative alt="{dk:screenZoneMeta/sp:title}">
												<xsl:choose>
													<xsl:when test="$vZoneArea &lt; $vArea*0.1 or $vHeight &lt; $vImgProps/@nativeHeight*0.4 or $vWidth &lt; $vImgProps/@nativeWidth*0.4">
														<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(../sp:img/@sc:refUri), '_Acrop/xhtmlContent'),concat(dk:screenZoneMeta/sp:geo/sp:coords,',200,200'))" disable-output-escaping="yes"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(../sp:img/@sc:refUri), '_Ahighlight/xhtmlContent'),concat(dk:screenZoneMeta/sp:geo/sp:coords,',200,200'))" disable-output-escaping="yes"/>
													</xsl:otherwise>
												</xsl:choose>
											</alternative>
										</td>
										<td class="screenZone_co">
											<xsl:value-of select="getContent(gotoSubModel(.),'')" disable-output-escaping="yes"/>
										</td>
									</tr>
								</table>
								<div class="screenZoneEnd">
									<xsl:if test="count(preceding-sibling::sp:zone)&gt;4">
										<a href="#{$vImgId}" title="Retourner à l&apos;écran">
											<span>Retourner à l&apos;écran</span>
										</a>
									</xsl:if>
								</div>
							</li>
						</xsl:for-each>
					</ol>
				</div>
			</div>
		</scBlock>
	</xsl:template>
	<xsl:template match="sp:zone" mode="zones">
		<xsl:variable name="vLeft" select="number(returnFirst(substring-before(dk:screenZoneMeta/sp:geo/sp:coords,','),0))"/>
		<xsl:variable name="vTop" select="number(returnFirst(substring-before(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),0))"/>
		<xsl:variable name="vWidth" select="number(returnFirst(substring-before(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',') - $vLeft,0))"/>
		<xsl:variable name="vHeight" select="number(returnFirst(substring-after(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',') - $vTop,0))"/>
		<xsl:variable name="vZneArea" select="$vWidth * $vHeight * $vRatio * $vRatio"/>
		<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
		<a class="screenZoneLnk{si($vZneArea &lt; $vSmallZoneLimit, 'Small', '')}" href="#{concat($vId,generate-id(.))}" style="position:absolute;top:{round($vTop * $vRatio)}px;left:{round($vLeft * $vRatio)}px;width:{round($vWidth * $vRatio)}px;height:{round($vHeight * $vRatio)}px;">
			<xsl:if test="dk:screenZoneMeta/sp:title">
				<addAttribute name="title" filter="textOnly">
					<xsl:value-of select="$vZneNum"/> - <xsl:value-of select="dk:screenZoneMeta/sp:title"/>
				</addAttribute>
			</xsl:if>
			<span>
				<xsl:value-of select="$vZneNum"/>
			</span>
		</a>
	</xsl:template>
	<xsl:template match="node()" mode="zones"/>
</xsl:stylesheet>
